#!/usr/bin/env python
"""KhtEditor a source code editor by Khertan"""
import khweeteur
import sys

if __name__ == '__main__':
    sys.exit(khweeteur.Khweeteur().exec_())
